@@ -2,12 +2,12 @@ package Egg::Plugin::Debugging;
 #
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Debugging.pm 154 2007-05-17 03:01:31Z lushe $
+# $Id: Debugging.pm 155 2007-05-20 04:05:33Z lushe $
 #
 use strict;
 use warnings;
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 
 =head1 NAME
 
@@ -53,8 +53,7 @@ sub notes {
 	my $self= shift;
 	my $msg = $_[1] ? join("\n", @_): ($_[0] || return 0);
 	   $msg =~s{[\r\n]+$} [];
-	$self->e->{egg_startup}
-	   ? do { print STDERR "$msg\n" }: do { $self->{notes}.= "$msg\n" };
+	print STDERR "$msg\n";
 }
 
 =head2 output
